summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--app/main.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/app/main.cpp b/app/main.cpp
index fab15e8..f555475 100644
--- a/app/main.cpp
+++ b/app/main.cpp
@@ -112,9 +112,9 @@ int main(int argc, char *argv[])
// HomeScreen
hs->init(port, token.c_str());
- // Set the event handler for Event_TapShortcut which will activate the surface for windowmanager
- hs->set_event_handler(LibHomeScreen::Event_TapShortcut, [qwm, &graphic_role](json_object *object){
- qDebug("Surface %s got tapShortcut\n", graphic_role.toStdString().c_str());
+ // Set the event handler for Event_ShowWindow which will activate the surface for windowmanager
+ hs->set_event_handler(LibHomeScreen::Event_ShowWindow, [qwm, &graphic_role](json_object *object){
+ qDebug("Surface %s got showWindow\n", graphic_role.toStdString().c_str());
qwm->activateWindow(graphic_role);
});